tic
clear
%close all
addpath(genpath('/Users/ananth/Documents/MATLAB/CustomFunctions')) % my custom functions
addpath(genpath('/Users/ananth/Documents/MATLAB/ImagingAnalysis')) % Additional functions
addpath(genpath('/Users/ananth/Documents/MATLAB/ImagingAnalysis/Suite2P-ananth'))
addpath('/Users/ananth/Documents/MATLAB/ImagingAnalysis/Suite2P-ananth/localCopies')

% Dataset details
make_db

%Operations
ops0.fig                       = 1;
ops0.saveData                  = 1;
ops0.onlyProbeTrials           = 0;
ops0.loadSyntheticData         = 1;
ops0.doSigOnly                 = 0;

if ops0.fig
    figureDetails = compileFigureDetails(20, 2, 10, 0.5, 'jet'); %(fontSize, lineWidth, markerSize, transparency, colorMap)
end

if ops0.loadSyntheticData
    setupSyntheticDataParameters
end
fprintf('Analyzing %s_%i_%i - Date: %s\n', db.mouseName, ...
    db.sessionType, ...
    db.session, ...
    db.date)

saveDirec = '/Users/ananth/Desktop/Work/Analysis/Imaging/';
saveFolder = [saveDirec db.mouseName '/' db.date '/'];

%for i = 1:length(sdcp)
%i = 1;
i = length(sdcp);
if ops0.loadSyntheticData
    load([saveFolder ...
        'synthDATA' ...
        '_tCP' num2str(sdcp(i).timeCellPercent) ...
        '_cO' lower(sdcp(i).cellOrder) ...
        '_mHTP' num2str(sdcp(i).maxHitTrialPercent) ...
        '_hTPA' lower(sdcp(i).hitTrialPercentAssignment) ...
        '_tO' lower(sdcp(i).trialOrder) ...
        '_eW' num2str(sdcp(i).eventWidth{1}) ...
        '_eAF' num2str(sdcp(i).eventAmplificationFactor) ...
        '_eT' lower(sdcp(i).eventTiming) ...
        '_sF' num2str(sdcp(i).startFrame) ...
        '_eF' num2str(sdcp(i).endFrame) ...
        '_iFWHM' num2str(sdcp(i).imprecisionFWHM) ...
        '_iT' lower(sdcp(i).imprecisionType) ...
        '_n' lower(sdcp(i).noise) ...
        '_np' num2str(sdcp(i).noisePercent) ...
        '.mat']);
    myData.dfbf = sdo.syntheticDATA;
    myData.dfbf_2D = sdo.syntheticDATA_2D;
    myData.baselines = zeros(size(sdo.syntheticDATA)); %initialization
else
    %Load processed data (processed dfbf for dataset/session)
    myData = load([saveFolder db.mouseName '_' db.date '.mat']);
end
trialDetails = getTrialDetails(db);

%Significant-Only Traces
if ops0.doSigOnly
    if ops0.onlyProbeTrials
        disp('Only analysing Probe Trials ...')
        dfbf_sigOnly = findSigOnly(myData.dfbf(:, iProbeTrials, :));
    else
        dfbf_sigOnly = findSigOnly(myData.dfbf);
    end
    DATA = dfbf_sigOnly;
else
    DATA = myData.dfbf;
end

mBInput.delta = 3;
mBInput.whichTrials = 'alternate';
mBInput.labelShuffle = 'off';
williamInput.distribution4Bayes = 'mvmn';
[mBOutput] = runWilliamTIAnalysis(DATA, mBInput);
mBOutput.normQ = (mBOutput.Q) ./max(mBOutput.Q);

if ops0.fig
    figure(1)
    subplot(1, 3, 1)
    plot(mBOutput.Yfit_actual, 'k*')
    title('Ground Truth', ...
        'FontSize', figureDetails.fontSize, ...
        'FontWeight', 'bold')
    xlabel('All Frames', ...
        'FontSize', figureDetails.fontSize, ...
        'FontWeight', 'bold')
    ylabel('Trial Frame Number', ...
        'FontSize', figureDetails.fontSize, ...
        'FontWeight', 'bold')
    set(gca,'FontSize', figureDetails.fontSize-3)
    
    subplot(1, 3, 2)
    plot(mBOutput.Yfit, 'bo')
    title('Prediction', ...
        'FontSize', figureDetails.fontSize, ...
        'FontWeight', 'bold')
    xlabel('All Frames', ...
        'FontSize', figureDetails.fontSize, ...
        'FontWeight', 'bold')
    ylabel('Trial Frame Number', ...
        'FontSize', figureDetails.fontSize, ...
        'FontWeight', 'bold')
    set(gca,'FontSize', figureDetails.fontSize-3)
    
    subplot(1, 3, 3)
    plot(mBOutput.YfitDiff, 'r')
    title('Error', ...
        'FontSize', figureDetails.fontSize, ...
        'FontWeight', 'bold')
    xlabel('All Frames', ...
        'FontSize', figureDetails.fontSize, ...
        'FontWeight', 'bold')
    ylabel('Difference in Frame Number', ...
        'FontSize', figureDetails.fontSize, ...
        'FontWeight', 'bold')
    set(gca,'FontSize', figureDetails.fontSize-3)
    
    print(['/Users/ananth/Desktop/' mBInput.labelShuffle], ...
        '-dpng')
    
    figure(2)
    subplot(1, 3, 1)
    imagesc(mBOutput.Yfit_actual_2D)
    colormap('jet')
    z = colorbar;
    ylabel(z,'Frame Number', ...
        'FontSize', figureDetails.fontSize, ...
        'FontWeight', 'bold')
    title('Ground Truth', ...
        'FontSize', figureDetails.fontSize, ...
        'FontWeight', 'bold')
    xlabel('Frame Number', ...
        'FontSize', figureDetails.fontSize, ...
        'FontWeight', 'bold')
    ylabel('Testing Trial Number', ...
        'FontSize', figureDetails.fontSize, ...
        'FontWeight', 'bold')
    set(gca,'FontSize', figureDetails.fontSize-3)
    
    subplot(1, 3, 2)
    imagesc(mBOutput.Yfit_2D)
    z = colorbar;
    ylabel(z,'Frame Number', ...
        'FontSize', figureDetails.fontSize, ...
        'FontWeight', 'bold')
    title('Prediction', ...
        'FontSize', figureDetails.fontSize, ...
        'FontWeight', 'bold')
    xlabel('Frame Number', ...
        'FontSize', figureDetails.fontSize, ...
        'FontWeight', 'bold')
    ylabel('Testing Trial Number', ...
        'FontSize', figureDetails.fontSize, ...
        'FontWeight', 'bold')
    set(gca,'FontSize', figureDetails.fontSize-3)
    
    subplot(1, 3, 3)
    imagesc(mBOutput.YfitDiff_2D)
    z = colorbar;
    ylabel(z,'Difference in Frame Numbers', ...
        'FontSize', figureDetails.fontSize, ...
        'FontWeight', 'bold')
    title('Error', ...
        'FontSize', figureDetails.fontSize, ...
        'FontWeight', 'bold')
    xlabel('Frame Number', ...
        'FontSize', figureDetails.fontSize, ...
        'FontWeight', 'bold')
    ylabel('Testing Trial Number', ...
        'FontSize', figureDetails.fontSize, ...
        'FontWeight', 'bold')
    set(gca,'FontSize', figureDetails.fontSize-3)
    
    print(['/Users/ananth/Desktop/2D_' mBInput.labelShuffle], ...
        '-dpng')
end

toc